#!/usr/bin/env python
# coding: utf-8

import sys
import os
import re

if sys.version_info[:2] < (2, 5):
    raise SystemExit("Python >=2.5 required")

from distutils.core import setup
from distutils.sysconfig import get_config_var

# Determine version number.
text = open(os.path.join(os.path.dirname(sys.argv[0]), "libcan/__init__.py")).read()
match = re.search(r'^__version__ = "([^"]+)"', text, re.M)
version = match.group(1)

kwargs = {
    "name":         "can",
    "version":      version,
    "author":       "Lars Gustäbel",
    "author_email": "lars@gustaebel.de",
    "url":          "http://www.gustaebel.de/lars/can/",
    "description":  "a simple incremental backup program similar to tar",
    "long_description":
                    "can is a utility to create and manage incremental snapshots of parts "\
                    "of the filesystem for backup purposes. It is very similar to the tar "\
                    "program in terms of command line options and handling.",
    "download_url": "http://www.gustaebel.de/lars/can/can-%s.tar.gz" % version,
    "license":      "GPL",
    "classifiers":  ["Development Status :: 5 - Production/Stable",
                    "Environment :: Console",
                    "Intended Audience :: System Administrators",
                    "License :: OSI Approved :: GNU General Public License (GPL)",
                    "Natural Language :: English",
                    "Operating System :: Unix",
                    "Programming Language :: Python",
                    "Topic :: System :: Archiving :: Backup",
                    "Topic :: Utilities"],
    "packages":     ["libcan"],
    "scripts":      ["can"],
    "data_files":   [(os.path.join(get_config_var("MANDIR"), "man1"), ["doc/can.1"]),
                     ("/etc/can", ["misc/compressed.list"])]
}

setup(**kwargs)

